==> storage-manager-wrapper-1.0.0-20121012.044741-112-sources.jar: org/gcube/contentmanager/storageclient/test/ISClientTest.java <==
/**
 * 
 */
package org.gcube.contentmanager.storageclient.test;


import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.gcube.common.core.scope.GCUBEScope;
import org.gcube.contentmanagement.blobstorage.service.IClient;
import org.gcube.contentmanager.storageclient.wrapper.AccessType;
import org.gcube.contentmanager.storageclient.wrapper.StorageClient;
import org.xml.sax.InputSource;

/**
 * @author rcirillo
 *
 */
public class ISClientTest {

	/**
	 * @param args
	 * @throws Exception 
	 */
	
	public static void main(String[] args) throws Exception {
		GCUBEScope scope = GCUBEScope.getScope("/gcube/devsec");
		IClient client=new StorageClient("PortletsUser", "HomeLibrary", "HomeLibrary-ContentManager", AccessType.SHARED, scope, null).getClient();
		String localFile="/home/rcirillo/FilePerTest/minni.jpg";
		String remoteFile="/img/pluto.jpg";
//		String key4unlock="4ee623e4e4b0b96037815e531323705317092";
		String newFile="/home/rcirillo/FilePerTest/new13.jpg";
//		long start=System.currentTimeMillis();
//		System.out.println("start upload file: "+localFile);
		String id=client.put(true).LFile(localFile).RFile(remoteFile);
		client.get().LFile(newFile).RFile(remoteFile);
//		client.removeDir().RDir("/");
	}
	
	
	private static void parseXmlFile(InputSource body){
		try{
		//get the factory
		  DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		  DocumentBuilder db = dbf.newDocumentBuilder();
		  Document doc = db.parse(body);
		  doc.getDocumentElement().normalize();
		  System.out.println("Root element " + doc.getDocumentElement().getNodeName());
		  NodeList nodeLst = doc.getElementsByTagName("server_list");
		  System.out.println("Information of all servers "+nodeLst.getLength());
		  int i=0;
		  for (int s = 0; s < nodeLst.getLength(); s++) {
		    Node fstNode = nodeLst.item(s);
		    if (fstNode.getNodeType() == Node.ELEMENT_NODE) {
		      Element fstElmnt = (Element) fstNode;
		      NodeList fstNmElmntLst = fstElmnt.getElementsByTagName("server");
		      Element fstNmElmnt = (Element) fstNmElmntLst.item(0);
		      String[] list=new String[nodeLst.getLength()];
		      String ip=fstNmElmnt.getAttribute("ip");
		      String port=fstNmElmnt.getAttribute("port");
		      System.out.println("ip: "+ip+" port: "+port);
		      list[i]=ip;
		      System.out.println("list["+i+"]: "+list[i]);
		      i++;
		    }
		  }
		} catch (Exception e) {
		   e.printStackTrace();
		}
	}

}

==> storage-manager-wrapper-1.0.2-20130409.125445-1-sources.jar: org/gcube/contentmanager/storageclient/test/ISClientTest.java <==
/**
 * 
 */
package org.gcube.contentmanager.storageclient.test;


import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.gcube.common.core.scope.GCUBEScope;
import org.gcube.contentmanagement.blobstorage.service.IClient;
import org.gcube.contentmanager.storageclient.wrapper.AccessType;
import org.gcube.contentmanager.storageclient.wrapper.StorageClient;
import org.xml.sax.InputSource;

/**
 * @author rcirillo
 *
 */
public class ISClientTest {

	/**
	 * @param args
	 * @throws Exception 
	 */
	
	public static void main(String[] args) throws Exception {
		GCUBEScope scope = GCUBEScope.getScope("/gcube/devsec");
		IClient client=new StorageClient("PortletsUser", "HomeLibrary", "HomeLibrary-ContentManager", AccessType.SHARED, scope, "").getClient();
		String localFile="/home/rcirillo/FilePerTest/minni.jpg";
		String remoteFile="/img/pluto.jpg";
//		String key4unlock="4ee623e4e4b0b96037815e531323705317092";
		String newFile="/home/rcirillo/FilePerTest/new13.jpg";
//		long start=System.currentTimeMillis();
//		System.out.println("start upload file: "+localFile);
		String id=client.put(true).LFile(localFile).RFile(remoteFile);
		client.get().LFile(newFile).RFile(remoteFile);
//		client.removeDir().RDir("/");
	}
	
	
	private static void parseXmlFile(InputSource body){
		try{
		//get the factory
		  DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		  DocumentBuilder db = dbf.newDocumentBuilder();
		  Document doc = db.parse(body);
		  doc.getDocumentElement().normalize();
		  System.out.println("Root element " + doc.getDocumentElement().getNodeName());
		  NodeList nodeLst = doc.getElementsByTagName("server_list");
		  System.out.println("Information of all servers "+nodeLst.getLength());
		  int i=0;
		  for (int s = 0; s < nodeLst.getLength(); s++) {
		    Node fstNode = nodeLst.item(s);
		    if (fstNode.getNodeType() == Node.ELEMENT_NODE) {
		      Element fstElmnt = (Element) fstNode;
		      NodeList fstNmElmntLst = fstElmnt.getElementsByTagName("server");
		      Element fstNmElmnt = (Element) fstNmElmntLst.item(0);
		      String[] list=new String[nodeLst.getLength()];
		      String ip=fstNmElmnt.getAttribute("ip");
		      String port=fstNmElmnt.getAttribute("port");
		      System.out.println("ip: "+ip+" port: "+port);
		      list[i]=ip;
		      System.out.println("list["+i+"]: "+list[i]);
		      i++;
		    }
		  }
		} catch (Exception e) {
		   e.printStackTrace();
		}
	}

}
